<?php

// Start the engine
require_once(TEMPLATEPATH.'/lib/init.php');

require_once( 'lib/init.php' );

// Calls the theme's constants & files
wsm_init();

// Child theme (do not remove)
define( 'CHILD_THEME_NAME', 'Ellen Mae Child Theme' );
define( 'CHILD_THEME_URL', 'http://www.web-savvy-marketing.com/website-design/' );

// Editor Styles
add_editor_style( 'editor-style.css' );

// Create additional color style options

add_theme_support( 'genesis-style-selector', 
	array( 
		'ellen-blue' => 'Blue',
		'ellen-brown' => 'Brown',
		'ellen-burgundy' => 'Burgundy',
		'ellen-mixed' => 'Mixed', 
		'ellen-pink' => 'Pink',
		'ellen-purple' => 'Purple',
	) 
);


// Add Viewport meta tag for mobile browsers
add_action( 'genesis_meta', 'wsm_add_viewport_meta_tag' );
function wsm_add_viewport_meta_tag() {
    echo '<meta name="viewport" content="width=device-width, initial-scale=1.0"/>';
}

// Structural Wrap
add_theme_support( 'genesis-structural-wraps', array( 'header', 'nav', 'subnav', 'inner', 'footer-widgets', 'footer' ) );


/* 
 * Add support for targeting individual browsers via CSS
 * See readme file located at /lib/js/css_browser_selector_readm.html
 * for a full explanation of available browser css selectors.
 */
add_action('get_header', 'wsm_load_scripts');
function wsm_load_scripts() {
    wp_enqueue_script('browserselect', CHILD_URL.'/lib/js/css_browser_selector.js', array('jquery'), '0.4.0', TRUE);
}

// Force Stupid IE to NOT use compatibility mode
add_action('genesis_meta','wsm_keep_ie_modern');
function wsm_keep_ie_modern() {
	echo '<meta http-equiv="X-UA-Compatible" content="IE=edge" />'."\n";
}
 
// Add new image sizes
add_image_size('Blog Thumbnail', 75, 73, TRUE);


// Modify the size of the Gravatar in the author box
add_filter( 'genesis_author_box_gravatar_size', 'wsm_author_box_gravatar_size' );
function wsm_author_box_gravatar_size($size) {
    return '60';
}

// Customize the post meta function
add_filter( 'genesis_post_meta', 'wsm_post_meta_filter' );
function wsm_post_meta_filter($post_meta) {
	if (is_single() ) {
    	$post_meta = '[post_categories sep=", " before="<div class=\'post-categories\'>Categories: " after="</div>"] [post_tags sep=", " before="<div class=\'post-tags\'>Tags: " after="</div>"]';
    	return $post_meta;
	}
}

// Modify Post Info
add_filter('genesis_post_info', 'wsm_post_info_filter');
function wsm_post_info_filter($post_info) {
if (!is_page()) {
  $post_info = '[post_date format="m.j.y" before="Posted on "] | [post_comments]'; //remove spaces after initial [
  //$post_info = 'Custom text'; //edit this to whatever you'd like.
}
return $post_info;
}

/** Modify the length of post excerpts */
add_filter( 'excerpt_length', 'wsm_custom_excerpt_length' );
function wsm_custom_excerpt_length($length) {
    return 48; // pull first 48 words
}


// Add Read More button to blog page and archives
add_filter( 'excerpt_more', 'wsm_add_excerpt_more' );
add_filter( 'get_the_content_more_link', 'wsm_add_excerpt_more' );
add_filter( 'the_content_more_link', 'wsm_add_excerpt_more' );
function wsm_add_excerpt_more( $more ) {
    return '<a class="more-link" href="' . get_permalink() . '" rel="nofollow">Read More ></a>';
}



/** Modify the speak your mind text */
add_filter( 'genesis_comment_form_args', 'wsm_custom_comment_form_args' );
function wsm_custom_comment_form_args($args) {
    $args['title_reply'] = 'Leave a Comment';
    return $args;
}

//Add titles to Post and Category
add_action('genesis_before_loop', 'wsm_replace_arch_titles');
function wsm_replace_arch_titles() {
	if ( is_category()) {
		echo '<div class="page-title"><h3 class="entry-title">';
		$category = get_the_category('');
		echo $category[0]->cat_name;
		echo '</h3></div>';
	}
	
	elseif ( is_single() ) {
		echo '<div class="page-title"><h3 class="entry-title">Blog</h3></div>';
	}
}

/** Reposition Blog title */
add_action( 'genesis_before_loop', 'wsm_page_heading');
function wsm_page_heading() {
	if ( is_page_template( 'page_blog.php' ) ) {
		echo '<div class="page-title">';
		echo '<div class="page-title"><h3 class="entry-title">Blog</h3></div>';
		remove_action( 'genesis_post_title', 'wsm_replace_arch_titles' );		
		echo '</div>';
	}
	
}

/** Remove Category Headline Title Description*/
remove_action( 'genesis_before_loop', 'genesis_do_taxonomy_title_description', 15 );

/* 
 * Add support for gravity form Deafault Field value
 */
 add_action('get_header', 'wsm_gform_scripts');
function wsm_gform_scripts() {
    wp_enqueue_script( 'gravityform', CHILD_URL . '/lib/js/gravityform.js', array('jquery'), '1.0', TRUE);
}

/* 
 * Add support for Font Resizer
 */
 add_action('get_header', 'wsm_font_resizer');
function wsm_font_resizer() {
    wp_enqueue_script( 'font-resizer', CHILD_URL . '/lib/js/font-resizer.js', array('jquery'), '1.0', TRUE);
}

// Changes Default Navigation to Primary & Footer

add_theme_support ( 'genesis-menus' , 
	array ( 
		'primary' => 'Primary Navigation Menu' ,
	) 
);


// Remove Layouts
genesis_unregister_layout( 'content-sidebar-sidebar' );
genesis_unregister_layout( 'sidebar-sidebar-content' );
genesis_unregister_layout( 'sidebar-content-sidebar' );

// Setup Sidebars
unregister_sidebar( 'header-right' );
unregister_sidebar( 'sidebar-alt' );
unregister_sidebar( 'sidebar' );


genesis_register_sidebar( array(
	'id'			=> 'rotator',
	'name'			=> __( 'Rotator', 'ellen' ),
	'description'	=> __( 'This is the image rotator section.', 'ellen' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-cta',
	'name'			=> __( 'Home CTA Area', 'ellen' ),
	'description'	=> __( 'This is the Home page CTA Boxes section.', 'ellen' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-main-content',
	'name'			=> __( 'Home Main Content', 'ellen' ),
	'description'	=> __( 'This is the Homepage Main Content section.', 'ellen' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-sidebar',
	'name'			=> __( 'Home Sidebar', 'ellen' ),
	'description'	=> __( 'This is the Homepage Sidebar.', 'ellen' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'blog-sidebar',
	'name'			=> __( 'Blog Sidebar', 'ellen' ),
	'description'	=> __( 'This is the Blog Page Sidebar.', 'ellen' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'page-sidebar',
	'name'			=> __( 'Page Sidebar', 'ellen' ),
	'description'	=> __( 'This is the Page Sidebar.', 'ellen' ),
) );

// Replace Footer With Custom Footer
remove_action('genesis_footer', 'genesis_do_footer');
add_action('genesis_footer', 'wsm_custom_footer');
function wsm_custom_footer() {
    require(CHILD_DIR.'/lib/structure/footer.php');
}

// Replace Header With Custom Header
remove_action ( 'genesis_header', 'genesis_do_header' );
add_action( 'genesis_header' , 'wsm_do_header' );
function wsm_do_header() {
	include_once( CHILD_DIR . '/lib/structure/header.php');
}

// add first and last classes to navigation
add_filter('wp_nav_menu', 'wsm_add_first_and_last');
function wsm_add_first_and_last($output) {
	$output = substr_replace($output, 'class="last-menu-item ', strripos($output, 'class="menu-item'), strlen('class="menu-item'));
	return $output;
}

// CSS Style for old IE
add_action('wp_head','wsm_rounded_corners');
function wsm_rounded_corners() {
	echo '<style type="text/css">';
	echo '#header .widget-area .phone, .home-top, .home-slider, #inner .wrap { behavior: url('.CHILD_URL.'/lib/js/pie/PIE.htc); }';
	echo '</style>';
}
