<?php
/**
 * Ellen Settings
 *
 * This file registers all of Ellen's specific Theme Settings, accessible from
 * Genesis --> Ellen Settings.
 *
 * NOTE: Change out "Ellen" in this file with name of theme and delete this note
 */ 
 
/**
 * Registers a new admin page, providing content and corresponding menu item
 * for the Child Theme Settings page.
 *
 * @since 1.0.0
 *
 * @package Ellen
 * @subpackage WSM_Ellen_Settings
 */
class WSM_Ellen_Settings extends Genesis_Admin_Boxes {
	
	/**
	 * Create an admin menu item and settings page.
	 * @since 1.0.0
	 */
	function __construct() {
		
		// Specify a unique page ID. 
		$page_id = 'ellen';
		
		// Set it as a child to genesis, and define the menu and page titles
		$menu_ops = array(
			'submenu' => array(
				'parent_slug' => 'genesis',
				'page_title'  => 'Ellen Mae Settings',
				'menu_title'  => 'Ellen Mae Settings',
				'capability' => 'manage_options',
			)
		);
		
		// Set up page options. These are optional, so only uncomment if you want to change the defaults
		$page_ops = array(
		//	'screen_icon'       => 'options-general',
		//	'save_button_text'  => 'Save Settings',
		//	'reset_button_text' => 'Reset Settings',
		//	'save_notice_text'  => 'Settings saved.',
		//	'reset_notice_text' => 'Settings reset.',
		);		
		
		// Give it a unique settings field. 
		// You'll access them from genesis_get_option( 'option_name', 'ellen-settings' );
		$settings_field = 'ellen-settings';
		
		// Set the default values
		$default_settings = array(	
			'wsm_copyright' => 'Copyright &copy; My Name, All Rights Reserved',
			'wsm_contact_phone' => '123.456.7890',
			'wsm_contact_address' => '123 Streetname, Anytown, US 12345',
		);
		
		// Create the Admin Page
		$this->create( $page_id, $menu_ops, $page_ops, $settings_field, $default_settings );

		// Initialize the Sanitization Filter
		add_action( 'genesis_settings_sanitizer_init', array( $this, 'sanitization_filters' ) );
			
	}

	/** 
	 * Set up Sanitization Filters
	 * @since 1.0.0
	 *
	 * See /lib/classes/sanitization.php for all available filters.
	 */	
	function sanitization_filters() {
		
		genesis_add_option_filter( 'no_html', $this->settings_field,
			array(
				'wsm_copyright',
				'wsm_contact_phone',
			) );
			
	genesis_add_option_filter( 'safe_html', $this->settings_field,
			array(	
				'wsm_contact_address',
			) );		
			
			
	}
	
	/**
	 * Set up Help Tab
	 * @since 1.0.0
	 *
	 * Genesis automatically looks for a help() function, and if provided uses it for the help tabs
	 * @link http://wpdevel.wordpress.com/2011/12/06/help-and-screen-api-changes-in-3-3/
	 */
	 function help() {
	 	$screen = get_current_screen();

		$screen->add_help_tab( array(
			'id'      => 'sample-help', 
			'title'   => 'Sample Help',
			'content' => '<p>Help content goes here.</p>',
		) );
	 }
	
	/**
	 * Register metaboxes on Child Theme Settings page
	 * @since 1.0.0
	 */
	function metaboxes() {

		add_meta_box('wsm_header_info_metabox', 'Header Info', array( $this, 'wsm_header_info_metabox' ), $this->pagehook, 'main', 'high');
		add_meta_box('wsm_footer_info_metabox', 'Footer Info', array( $this, 'wsm_footer_info_metabox' ), $this->pagehook, 'main', 'high');
				
	}
	
	/**
	 * Footer Info Metabox
	 * @since 1.0.0
	 */
	function wsm_footer_info_metabox() {

		echo '<p><strong>Copyright Info:</strong></p>';
		echo '<p><input type="text" name="' . $this->get_field_name( 'wsm_copyright' ) . '" id="' . $this->get_field_id( 'wsm_copyright' ) . '" value="' . esc_attr( $this->get_field_value( 'wsm_copyright' ) ) . '" size="70" /></p>';
	
	}
	
	/**
	 * Header Info Metabox
	 * @since 1.0.0
	 */
	function wsm_header_info_metabox() {

		echo '<p><strong>Phone:</strong></p>';
		echo '<p><input type="text" name="' . $this->get_field_name( 'wsm_contact_phone' ) . '" id="' . $this->get_field_id( 'wsm_contact_phone' ) . '" value="' . esc_attr( $this->get_field_value( 'wsm_contact_phone' ) ) . '" size="70" /></p>';	
		echo '<p><strong>Address:</strong></p>';
		echo '<p><input type="text" name="' . $this->get_field_name( 'wsm_contact_address' ) . '" id="' . $this->get_field_id( 'wsm_contact_address' ) . '" value="' . esc_attr( $this->get_field_value( 'wsm_contact_address' ) ) . '" size="70" /></p>';	
	}
	
}

/**
 * Add the Theme Settings Page
 * @since 1.0.0
 */
function wsm_add_ellen_settings() {
	global $_child_theme_settings;
	$_child_theme_settings = new WSM_Ellen_Settings;	 	
}
add_action( 'genesis_admin_menu', 'wsm_add_ellen_settings' );

/**
 * Add Soliloquy key
 *
 * @since 1.0.0
 */
// Soliloquy License
if ( ! get_option( 'soliloquy_license_key' ) )
	update_option( 'soliloquy_license_key', SOLILOQUY_LICENSE_KEY );
